@@ -562,8 +562,8 @@ def tunnel(env: Environment, address, target, ports):
     job_name = "port-forwarder-{}".format(uuid.uuid4())
     # the intermediate port in the proxy pod
     base_port = 4180
-    # the time in seconds after which the port forwarding job gets cleanup up
-    job_ttl = 3600
+    # the time in seconds after which the port forwarding job gets terminated and cleaned up
+    timeout = 3600
 
     # remove any resources we created when shutting down
     @atexit.register
@@ -577,10 +577,10 @@ def tunnel(env: Environment, address, target, ports):
     kube_config.update_token()
 
     # generate socat container specs for each port
-    containers = generate_containers(target, ports, base_port)
+    containers = generate_containers(target, ports, base_port, timeout)
 
     # template of the job to apply
-    job_spec = generate_job(containers, job_name, job_ttl)
+    job_spec = generate_job(containers, job_name, timeout)
 
     # submit the job to kubernetes
     cmdline = ("apply", "-f", "-")
@@ -645,19 +645,19 @@ def latest_socat_image():
     return "{}/{}/{}:{}".format(docker_registry, team, artifact, production_ready_images[-1]["name"])
 
 
-def generate_containers(target, ports, base_port):
+def generate_containers(target, ports, base_port, timeout):
     containers = []
     socat_image = latest_socat_image()
 
     for i, port in enumerate(ports):
         local_port = base_port + i
         remote_port = port[-1]
-        containers.append(generate_container(target, local_port, remote_port, socat_image))
+        containers.append(generate_container(target, local_port, remote_port, socat_image, timeout))
 
     return containers
 
 
-def generate_container(target, local_port, remote_port, socat_image):
+def generate_container(target, local_port, remote_port, socat_image, timeout):
     return {
         "name": "socat-{}".format(remote_port),
         "image": socat_image,
@@ -667,6 +667,12 @@ def generate_container(target, local_port, remote_port, socat_image):
             "TCP-LISTEN:{},fork,bind=0.0.0.0".format(local_port),
             "TCP:{}:{}".format(target, remote_port),
         ],
+        "env": [
+            {
+                "name": "TIMEOUT",
+                "value": str(timeout),
+            }
+        ],
         "resources": {"limits": {"cpu": "10m", "memory": "128Mi"}},
         "securityContext": {
             "runAsNonRoot": True,
@@ -677,17 +683,18 @@ def generate_container(target, local_port, remote_port, socat_image):
     }
 
 
-def generate_job(containers, name, ttl):
+def generate_job(containers, name, timeout):
     return {
         "apiVersion": "batch/v1",
         "kind": "Job",
         "metadata": {
             "name": name,
             "labels": {"application": "teapot-port-forward"},
-            "annotations": {"janitor/ttl": "{}s".format(ttl)},
+            "annotations": {"janitor/ttl": "{}s".format(timeout)},
         },
         "spec": {
-            "activeDeadlineSeconds": ttl,
+            "activeDeadlineSeconds": timeout,
+            "backoffLimit": 0,
             "ttlSecondsAfterFinished": 0,
             "template": {
                 "metadata": {"labels": {"application": "teapot-port-forward"}},
